SpecViz: An interactive astronomical 1D spectra analysis tool
=============================================================

An GUI-based interactive analysis tool for one dimensional astronomical data
using Python.

For documentation see https://specviz.readthedocs.io/en/latest/

Current Status
--------------

Please note that this version of SpecViz is **no longer being actively supported
or maintained**. The functionality of SpecViz is now available and being actively
developed as part of `Jdaviz <https://github.com/spacetelescope/jdaviz>`_.

If you must use legacy SpecViz, please try v0.7.1 in Python 3.6.

License
-------

This project is Copyright (c) JDADF Developers and licensed under
the terms of the BSD 3-Clause license. This package is based upon
the `Astropy package template <https://github.com/astropy/package-template>`_
which is licensed under the BSD 3-clause licence. See the licenses folder for
more information.
